
===================
API  Documentation
===================

Swan classes
------------

Config
~~~~~~
.. automodule:: rompy_swan.config
    :members:
    :inherited-members: BaseModel
    :no-index:

Grid
~~~~
.. automodule:: rompy_swan.grid
    :members:
    :inherited-members: BaseModel
    :no-index:

Data
~~~~
.. automodule:: rompy_swan.data
    :members:
    :inherited-members: BaseModel
    :no-index:

Boundary
~~~~~~~~
.. automodule:: rompy_swan.boundary
    :members:
    :inherited-members: BaseModel
    :no-index:

Types
~~~~~
.. automodule:: rompy_swan.types
    :members:
    :inherited-members: BaseModel
    :no-index:


Swan components
---------------

Base
~~~~
.. automodule:: rompy_swan.components.base
    :members:
    :inherited-members: BaseModel
    :no-index:

Group
~~~~~
.. automodule:: rompy_swan.components.group
    :members:
    :inherited-members: BaseModel
    :no-index:

Startup
~~~~~~~
.. automodule:: rompy_swan.components.startup
    :members:
    :inherited-members: BaseModel
    :no-index:

Cgrid
~~~~~
.. automodule:: rompy_swan.components.cgrid
    :members:
    :inherited-members: BaseModel
    :no-index:

Inpgrid
~~~~~~~
.. automodule:: rompy_swan.components.inpgrid
    :members:
    :inherited-members: BaseModel
    :no-index:

Boundary
~~~~~~~~
.. automodule:: rompy_swan.components.boundary
    :members:
    :inherited-members: BaseModel
    :no-index:

Physics
~~~~~~~
.. automodule:: rompy_swan.components.physics
    :members:
    :inherited-members: BaseModel
    :no-index:

Numerics
~~~~~~~~
.. automodule:: rompy_swan.components.numerics
    :members:
    :inherited-members: BaseModel
    :no-index:


Swan subcomponents
------------------

Base
~~~~
.. automodule:: rompy_swan.subcomponents.base
    :members:
    :inherited-members: BaseModel
    :no-index:

Startup
~~~~~~~
.. automodule:: rompy_swan.subcomponents.startup
    :members:
    :inherited-members: BaseModel
    :no-index:

Spectrum
~~~~~~~~
.. automodule:: rompy_swan.subcomponents.spectrum
    :members:
    :inherited-members: BaseModel
    :no-index:

Time
~~~~
.. automodule:: rompy_swan.subcomponents.time
    :members:
    :inherited-members: BaseModel
    :no-index:

Readgrid
~~~~~~~~
.. automodule:: rompy_swan.subcomponents.readgrid
    :members:
    :inherited-members: BaseModel
    :no-index:

Boundary
~~~~~~~~
.. automodule:: rompy_swan.subcomponents.boundary
    :members:
    :inherited-members: BaseModel
    :no-index:

Physics
~~~~~~~
.. automodule:: rompy_swan.subcomponents.physics
    :members:
    :inherited-members: BaseModel
    :no-index:

Numerics
~~~~~~~~
.. automodule:: rompy_swan.subcomponents.numerics
    :members:
    :inherited-members: BaseModel
    :no-index:
